@@ -148,18 +148,11 @@ class SBHTTPSConnection(HTTPSConnection):
             sock.bind((self._src_ip, 0))
         sock.set_socket_read_timeout(self._timeout)
         sock.set_socket_write_timeout(self._timeout)
-        # try a few times
         # While using an unreliable connection, I've seen it fail with
-        # unexpected eof.
-        attempts = 0
-        while 1:
-            try:
-                sock.connect((self.host, self.port))
-                break
-            except SSLError:
-                attempts = attempts + 1
-                if attempts > 3:
-                    raise
+        # unexpected eof. Possibly check for SSLError and retry.
+        # First attempt at this resulted in Transport endpoint is already
+        # connected errors.
+        sock.connect((self.host, self.port))
 
 
 class SBHTTPS(HTTPS):
